==> stockpyle-0.0.3.tar.gz: stockpyle-0.0.3/stockpyle/__init__.py <==
# BSD License
# 
# Copyright (c) 2008, Matt Pizzimenti
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
# 
# Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
# Neither the name of the organization nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import stockpyle.stores as stores

__all__  = [
    "stores",
    # "Storable",
    ]


# class Storable(object):
#     
#     _store = None
#     
#     @classmethod
#     def bind_store(cls, store):
#         if cls._store:
#             raise StandardError("cannot bind object more than once")
#         else:
#             cls._store = store
#     
#     @classmethod
#     def unbind_store(cls):
#         cls._store = None
#     
#     def put(self):
#         self.__class__._store.put(self)
#     
#     def delete(self):
#         self.__class__._store.delete(self)
#     
#     @classmethod
#     def get(cls, key):
#         return cls._store.get(cls, key)
#     
#     @classmethod
#     def batch_get(cls, keys):
#         return cls._store.batch_get(cls, keys)
#

==> stockpyle-0.0.5.tar.gz: stockpyle-0.0.5/stockpyle/__init__.py <==
# BSD License
# 
# Copyright (c) 2008, Matt Pizzimenti
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
# 
# Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
# Neither the name of the organization nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import stockpyle.stores as stores

__all__  = [
    "stores",
    # "Storable",
    ]


# class Storable(object):
#     
#     __stockpyle_store__ = None
#     
#     def put(self):
#         self.__class__._store.put(self)
#     
#     def delete(self):
#         self.__class__._store.delete(self)
#     
#     @classmethod
#     def get(cls, key):
#         return cls._store.get(cls, key)
#     
#     @classmethod
#     def batch_get(cls, keys):
#         return cls._store.batch_get(cls, keys)
#
